[**Opzioni avanzate**](./introduction.md) > **Codice lingua** _(current)_

---

#### Google

Fonte <https://developers.google.com/admin-sdk/directory/v1/languages?hl=zh-cn>, organizzato da GPT-4o.

| Etichetta in italiano | Etichetta | `Codice lingua` |
| --- | --- | --- |
| Amarico | Amharic | `am` |
| Arabo | Arabic | `ar` |
| 巴斯克语 | Basque | `eu` |
| Bengalese | Bengali | `bn` |
| Inglese (Regno Unito) | English (UK) | `en-GB` |
| Portoghese (Brasile) | Portuguese (Brazil) | `pt-BR` |
| 保加利亚语 | Bulgarian | `bg` |
| Catalano | Catalan | `ca` |
| 切罗基语 | Cherokee | `chr` |
| Croato | Croatian | `hr` |
| 捷克语 | Ceco | `cs` |
| Danese | `da` |
| Olandese | Dutch | `nl` |
| Inglese (Stati Uniti) | English (US) | `en` |
| 爱沙尼亚语 | Estonian | `et` |
| 菲律宾语 | Filipino | `fil` |
| 芬兰语 | Finnish | `fi` |
| Francese | French | `fr` |
| Tedesco | German | `de` |
| Greco | Greek | `el` |
| Gujarati | Gujarati | `gu` |
| Ebraico | Hebrew | `iw` |
| 印地语 | Hindi | `hi` |
| Ungherese | Hungarian | `hu` |
| 冰岛语 | Icelandic | `is` |
| 印度尼西亚语 | Indonesian | `id` |
| Italiano | Italian | `it` |
| 日语 | Japanese | `ja` |
| Kannada | `kn` |
| 意大利语 | Italian | `it` |
| 日语 | Japanese | `ja` | | 俄语 | Russian | `ru` |
| 法语 | French | `fr` | | 葡萄牙语 | Portuguese | `pt` |
| 德语 | German | `de` | | 阿拉伯语 | Arabic | `ar` |
| 西班牙语 | Spanish | `es` | | 印地语 | Hindi | `hi` |


| Coreano | Korean | `ko` | | Italiano | Italian | `it` |
| Giapponese | Japanese | `ja` | | Russo | Russian | `ru` |
| Francese | French | `fr` | | Portoghese | Portuguese | `pt` |
| Tedesco | German | `de` | | Arabo | Arabic | `ar` |
| Spagnolo | Spanish | `es` | | Hindi | Hindi | `hi` |
| 拉脱维亚语 | Latvian | `lv` |
| Lituano | Lithuanian | `lt` |
| 马来语 | Malay | `ms` |
| Malayalam | `ml` |
| Marathi | `mr` |
| 挪威语 | Norwegian | `no` |
| Polacco | `pl` |
| Portoghese (Portogallo) | Portuguese (Portugal) | `pt-PT` |
| Rumeno | Romanian | `ro` |
| Russo | Russian | `ru` |
| 塞尔维亚语 | Serbian | `sr` |
| Cinese (RPC) | Chinese (PRC) | `zh-CN` |
| Slovacco | Slovak | `sk` |
| Sloveno | Slovenian | `sl` |
| Spagnolo | Spanish | `es` |
| 斯瓦希里语 | Swahili | `sw` |
| Svedese | Swedish | `sv` |
| 泰米尔语 | Tamil | `ta` |
| 泰卢固语 | Telugu | `te` |
| 泰语 | Thai | `th` |
| Cinese (Taiwan) | Chinese (Taiwan) | `zh-TW` |
| 土耳其语 | Turkish | `tr` |
| Urdu | `ur` |
| 乌克兰语 | Ukrainian | `uk` |
| 越南语 | Vietnamese | `vi` |
| 威尔士语 | Welsh | `cy` |

#### DeepL

Fonte <https://developers.deepl.com/docs/resources/supported-languages>, organizzato da GPT-4o.

| Etichetta in italiano | Label | `Codice lingua` | Supporta |
| --- | --- | --- | --- |
| Arabo | Arabic | `AR` | `source`, `target` |
| Bulgaro | Bulgarian | `BG` | `source`, `target` |
| Ceco | Czech | `CS` | `source`, `target` |
| Danese | Danish | `DA` | `source`, `target` |
| Tedesco | German | `DE` | `source`, `target` |
| Greco | Greek | `EL` | `source`, `target` |
| 意大利语 | Italian | `IT` | `source`, `target` |
| 西班牙语 | Spanish | `ES` | `source`, `target` |
| 法语 | French | `FR` | `source`, `target` |
| 德语 | German | `DE` | `source`, `target` |
| 葡萄牙语 | Portuguese | `PT` | `source`, `target` |
| 俄语 | Russian | `RU` | `source`, `target` |
| 日语 | Japanese | `JA` | `source`, `target` |
| 韩语 | Korean | `KO` | `source`, `target` |
| 阿拉伯语 | Arabic | `AR` | `source`, `target` |
| 印地语 | Hindi | `HI` | `source`, `target` |
| 土耳其语 | Turkish | `TR` | `source`, `target` |
| 荷兰语 | Dutch | `NL` | `source`, `target` |
| 波兰语 | Polish | `PL` | `source`, `target` |
| 瑞典语 | Swedish | `SV` | `source`, `target` |
| 芬兰语 | Finnish | `FI` | `source`, `target` |
| 丹麦语 | Danish | `DA` | `source`, `target` |
| 挪威语 | Norwegian | `NO` | `source`, `target` |
| 希腊语 | Greek | `EL` | `source`, `target` |
| 捷克语 | Czech | `CS` | `source`, `target` |
| 匈牙利语 | Hungarian | `HU` | `source`, `target` |
| 罗马尼亚语 | Romanian | `RO` | `source`, `target` |
| 泰语 | Thai | `TH` | `source`, `target` |
| 越南语 | Vietnamese | `VI` | `source`, `target` |
| 印尼语 | Indonesian | `ID` | `source`, `target` |
| 马来语 | Malay | `MS` | `source`, `target` |
| 菲律宾语 | Filipino | `FIL` | `source`, `target` |
| 乌克兰语 | Ukrainian | `UK` | `source`, `target` |
| 加泰罗尼亚语 | Catalan | `CA` | `source`, `target` |
| 希伯来语 | Hebrew | `HE` | `source`, `target` |
| 克罗地亚语 | Croatian | `HR` | `source`, `target` |
| 斯洛伐克语 | Slovak | `SK` | `source`, `target` |
| 斯洛文尼亚语 | Slovenian | `SL` | `source`, `target` |
| 保加利亚语 | Bulgarian | `BG` | `source`, `target` |
| 塞尔维亚语 | Serbian | `SR` | `source`, `target` |
| 爱沙尼亚语 | Estonian | `ET` | `source`, `target` |
| 拉脱维亚语 | Latvian | `LV` | `source`, `target` |
| 立陶宛语 | Lithuanian | `LT` | `source`, `target` |
| 冰岛语 | Icelandic | `IS` | `source`, `target` |
| 阿尔巴尼亚语 | Albanian | `SQ` | `source`, `target` |
| 马其顿语 | Macedonian | `MK` | `source`, `target` |
| 白俄罗斯语 | Belarusian | `BE` | `source`, `target` |
| 格鲁吉亚语 | Georgian | `KA` | `source`, `target` |
| 亚美尼亚语 | Armenian | `HY` | `source`, `target` |
| 阿塞拜疆语 | Azerbaijani | `AZ` | `source`, `target` |
| 哈萨克语 | Kazakh | `KK` | `source`, `target` |
| 乌兹别克语 | Uzbek | `UZ` | `source`, `target` |
| 塔吉克语 | Tajik | `TG` | `source`, `target` |
| 吉尔吉斯语 | Kyrgyz | `KY` | `source`, `target` |
| 土库曼语 | Turkmen | `TK` | `source`, `target` |
| 蒙古语 | Mongolian | `MN` | `source`, `target` |
| 尼泊尔语 | Nepali | `NE` | `source`, `target` |
| 僧伽罗语 | Sinhala | `SI` | `source`, `target` |
| 高棉语 | Khmer | `KM` | `source`, `target` |
| 老挝语 | Lao | `LO` | `source`, `target` |
| 缅甸语 | Burmese | `MY` | `source`, `target` |
| 孟加拉语 | Bengali | `BN` | `source`, `target` |
| 泰米尔语 | Tamil | `TA` | `source`, `target` |
| 泰卢固语 | Telugu | `TE` | `source`, `target` |
| 马拉雅拉姆语 | Malayalam | `ML` | `source`, `target` |
| 卡纳达语 | Kannada | `KN` | `source`, `target` |
| 古吉拉特语 | Gujarati | `GU` | `source`, `target` |
| 马拉地语 | Marathi | `MR` | `source`, `target` |
| 旁遮普语 | Punjabi | `PA` | `source`, `target` |
| 信德语 | Sindhi | `SD` | `source`, `target` |
| 乌尔都语 | Urdu | `UR` | `source`, `target` |
| 波斯语 | Persian | `FA` | `source`, `target` |
| 普什图语 | Pashto | `PS` | `source`, `target` |
| 库尔德语 | Kurdish | `KU` | `source`, `target` |
| 豪萨语 | Hausa | `HA` | `source`, `target` |
| 约鲁巴语 | Yoruba | `YO` | `source`, `target` |
| 伊博语 | Igbo | `IG` | `source`, `target` |
| 斯瓦希里语 | Swahili | `SW` | `source`, `target` |
| 阿姆哈拉语 | Amharic | `AM` | `source`, `target` |
| 奥罗莫语 | Oromo | `OM` | `source`, `target` |
| 索马里语 | Somali | `SO` | `source`, `target` |
| 提格里尼亚语 | Tigrinya | `TI` | `source`, `target` |
| 阿非利卡语 | Afrikaans | `AF` | `source`, `target` |
| 祖鲁语 | Zulu | `ZU` | `source`, `target` |
| 科萨语 | Xhosa | `XH` | `source`, `target` |
| 绍纳语 | Shona | `SN` | `source`, `target` |
| 斯威士语 | Swati | `SS` | `source`, `target` |
| 文达语 | Venda | `VE` | `source`, `target` |
| 聪加语 | Tsonga | `TS` | `source`, `target` |
| 北索托语 | Northern Sotho | `NS` | `source`, `target` |
| 南索托语 | Southern Sotho | `ST` | `source`, `target` |
| 茨瓦纳语 | Tswana | `TN` | `source`, `target` |
| 卢旺达语 | Kinyarwanda | `RW` | `source`, `target` |
| 基隆迪语 | Kirundi | `RN` | `source`, `target` |
| 卢干达语 | Luganda | `LG` | `source`, `target` |
| 林加拉语 | Lingala | `LN` | `source`, `target` |
| 刚果语 | Kongo | `KG` | `source`, `target` |
| 桑戈语 | Sango | `SG` | `source`, `target` |
| 班巴拉语 | Bambara | `BM` | `source`, `target` |
| 曼丁哥语 | Mandingo | `MN` | `source`, `target` |
| 沃洛夫语 | Wolof | `WO` | `source`, `target` |
| 富拉尼语 | Fulani | `FF` | `source`, `target` |
| 摩尔语 | Moore | `MO` | `source`, `target` |
| 埃维语 | Ewe | `EE` | `source`, `target` |
| 特威语 | Twi | `TW` | `source`, `target` |
| 丰语 | Fon | `FN` | `source`, `target` |
| 约鲁巴语 | Yoruba | `YO` | `source`, `target` |
| 伊博语 | Igbo | `IG` | `source`, `target` |
| 豪萨语 | Hausa | `HA` | `source`, `target` |
| 斯瓦希里语 | Swahili | `SW` | `source`, `target` |
| 阿姆哈拉语 | Amharic | `AM` | `source`, `target` |
| 奥罗莫语 | Oromo | `OM` | `source`, `target` |
| 索马里语 | Somali | `SO` | `source`, `target` |
| 提格里尼亚语 | Tigrinya | `TI` | `source`, `target` |
| 阿非利卡语 | Afrikaans | `AF` | `source`, `target` |
| 祖鲁语 | Zulu | `ZU` | `source`, `target` |
| 科萨语 | Xhosa | `XH` | `source`, `target` |
| 绍纳语 | Shona | `SN` | `source`, `target` |
| 斯威士语 | Swati | `SS` | `source`, `target` |
| 文达语 | Venda | `VE` | `source`, `target` |
| 聪加语 | Tsonga | `TS` | `source`, `target` |
| 北索托语 | Northern Sotho | `NS` | `source`, `target` |
| 南索托语 | Southern Sotho | `ST` | `source`, `target` |
| 茨瓦纳语 | Tswana | `TN` | `source`, `target` |
| 卢旺达语 | Kinyarwanda | `RW` | `source`, `target` |
| 基隆迪语 | Kirundi | `RN` | `source`, `target` |
| 卢干达语 | Luganda | `LG` | `source`, `target` |
| 林加拉语 | Lingala | `LN` | `source`, `target` |
| 刚果语 | Kongo | `KG` | `source`, `target` |
| 桑戈语 | Sango | `SG` | `source`, `target` |
| 班巴拉语 | Bambara | `BM` | `source`, `target` |
| 曼丁哥语 | Mandingo | `MN` | `source`, `target` |
| 沃洛夫语 | Wolof | `WO` | `source`, `target` |
| 富拉尼语 | Fulani | `FF` | `source`, `target` |
| 摩尔语 | Moore | `MO` | `source`, `target` |
| 埃维语 | Ewe | `EE` | `source`, `target` |
| 特威语 | Twi | `TW` | `source`, `target` |
| 丰语 | Fon | `FN` | `source`, `target` |
| Inglese (Regno Unito) | English (British) | `EN-GB` | `target` |
| 英语（美国） | English (American) | `EN-US` | `target` |
| Spagnolo | Spanish | `ES` | `source`, `target` |
| Estone | Estonian | `ET` | `source`, `target` |
| Finlandese | Finnish | `FI` | `source`, `target` |
| Francese | French | `FR` | `source`, `target` |
| Ungherese | Hungarian | `HU` | `source`, `target` |
| Indonesiano | Indonesian | `ID` | `source`, `target` |
| Italiano | Italian | `IT` | `source`, `target` |
| 日语 | Japanese | `JA` | `source`, `target` |
| Coreano | Korean | `KO` | `source`, `target` |
| Lituano | Lithuanian | `LT` | `source`, `target` |
| Lettone | Latvian | `LV` | `source`, `target` |
| 挪威博克马尔语 | Norwegian Bokmål | `NB` | `source`, `target` |
| Olandese | Dutch | `NL` | `source`, `target` |
| Polacco | Polish | `PL` | `source`, `target` |
| Portoghese | Portuguese | `PT` | `source`, `target` |
| Portoghese (Brasile) | Portuguese (Brazilian) | `PT-BR` | `target` |
| Portoghese (Europeo) | Portuguese (European) | `PT-PT` | `target` |
| Rumeno | Romanian | `RO` | `source`, `target` |
| Russo | Russian | `RU` | `source`, `target` |
| Slovacco | Slovak | `SK` | `source`, `target` |
| Sloveno | Slovenian | `SL` | `source`, `target` |
| Svedese | Swedish | `SV` | `source`, `target` |
| 土耳其语 | Turkish | `TR` | `source`, `target` |
| Ucraino | Ukrainian | `UK` | `source`, `target` |
| 中文 | Chinese | `ZH` | `source`, `target` |
| 中文（简体） | Chinese (Simplified) | `ZH-HANS` | `target` |
| 中文（繁体） | Chinese (Traditional) | `ZH-HANT` | `target` |

<div align="right"> 
<h6><small>Parte del contenuto di questa pagina è stata tradotta da GPT e potrebbe contenere errori.</small></h6>